@@ -11,7 +11,7 @@ import sys
 # to stay secure?
 # TODO: Stop being lame and find a way to make this more secure.
 from importlib import import_module
-
+import getopt
 from wsunittest import *
 
 
@@ -54,9 +54,12 @@ class unittestWebSocketHandler(tornado.websocket.WebSocketHandler):
         if module:
             # TODO: Reload module if the module has already been loaded. (reload(module))
             # You may pass the port to the server by commandline; this removes it.
+
+            argv = sys.argv
             try:
-                argv = sys.argv
-                argv.pop(argv.index("port"))
+                for a in argv:
+                    if "--port=" in a:
+                        argv.pop(argv.index(a))
             except ValueError:
                 logging.warning(repr(argv))
             return unittestWebSocketTestProgram(
